@@ -19,10 +19,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-export PATH=/opt/searduino/bin:${PATH}
 export LD_LIBRARY_PATH=/opt/searduino/lib
 export PYTHONPATH=/opt/searduino/lib
-export DYLD_LIBRARY_PATH=/opt/searduino/lib
 
-/opt/searduino/bin/pardon.py $*
+/opt/searduino/bin/pardon.py
 
